com.digitalasset.transcode.codegen

Members list

Type members

Classlikes

trait Codegen

Attributes

Supertypes
class Object
trait Matchable
class Any
trait CodegenVisitor extends SchemaVisitor

Base type for code generators.

Base type for code generators.

Define potentially mutable Context to store compilation units during schema traversal. Be aware that schema cases can be called multiple types in case of recursive definitions in daml model.

Instances of codegen visitors can be shared and reused. Any state should be stored in transient Context instances only

Note that Type and Result are Context Functions which provide implicit Context instance in every handler method.

Attributes

Supertypes
trait SchemaVisitor
class Object
trait Matchable
class Any
sealed trait TypeInfo

Attributes

Companion
object
Supertypes
class Object
trait Matchable
class Any
Known subtypes
class Application
class FQN
object Wild
object TypeInfo

Attributes

Companion
trait
Supertypes
trait Sum
trait Mirror
class Object
trait Matchable
class Any
Self type
TypeInfo.type
object TypeUtils

Attributes

Supertypes
class Object
trait Matchable
class Any
Self type
TypeUtils.type

Value members

Concrete methods

def ImplementationVersion: String

Extensions

Extensions

extension (id: Identifier)
def canonicalPackageName: String
extension (path: RelPath)
def setExtension(ext: String): RelPath