com.digitalasset.transcode.codegen
Members list
Type members
Classlikes
trait Codegen
Attributes
- Supertypes
-
class Objecttrait Matchableclass Any
trait CodegenVisitor extends SchemaVisitor
Base type for code generators.
Base type for code generators.
Define potentially mutable Context to store compilation units during schema traversal. Be aware that schema cases can be called multiple types in case of recursive definitions in daml model.
Instances of codegen visitors can be shared and reused. Any state should be stored in transient Context instances only
Note that Type and Result are Context Functions which provide implicit Context instance in every handler method.
Attributes
- Supertypes
-
trait SchemaVisitorclass Objecttrait Matchableclass Any
Attributes
- Companion
- object
- Supertypes
-
class Objecttrait Matchableclass Any
- Known subtypes
object TypeInfo
Value members
Concrete methods
Extensions
Extensions
extension (id: Identifier)
extension (path: RelPath)
In this article