CodegenVisitor
Base type for code generators.
Define potentially mutable Context to store compilation units during schema traversal. Be aware that schema cases can be called multiple types in case of recursive definitions in daml model.
Instances of codegen visitors can be shared and reused. Any state should be stored in transient Context instances only
Note that Type and Result are Context Functions which provide implicit Context instance in every handler method.
Attributes
- Graph
-
- Supertypes
-
trait SchemaVisitorclass Objecttrait Matchableclass Any
Members list
Value members
Abstract methods
Inherited and Abstract methods
Type Application
Type Application
Attributes
- Inherited from:
- SchemaVisitor
Boolean
Boolean
Attributes
- Inherited from:
- SchemaVisitor
Wrap type into addressable DataType
Wrap type into addressable DataType
Attributes
- Inherited from:
- SchemaVisitor
Contract ID, parametrized with the processor for corresponding template
Contract ID, parametrized with the processor for corresponding template
Attributes
- Inherited from:
- SchemaVisitor
Date
Date
Attributes
- Inherited from:
- SchemaVisitor
ADT, Sum type - special case, where there are only named constructors without arguments
ADT, Sum type - special case, where there are only named constructors without arguments
Attributes
- Inherited from:
- SchemaVisitor
Map with keys and values of any type
Map with keys and values of any type
Attributes
- Inherited from:
- SchemaVisitor
8-byte Integer
8-byte Integer
Attributes
- Inherited from:
- SchemaVisitor
Sequence of elements
Sequence of elements
Attributes
- Inherited from:
- SchemaVisitor
Numeric with scale
Numeric with scale
Attributes
- Inherited from:
- SchemaVisitor
Optional element
Optional element
Attributes
- Inherited from:
- SchemaVisitor
Party
Party
Attributes
- Inherited from:
- SchemaVisitor
ADT, Product type
ADT, Product type
Attributes
- Inherited from:
- SchemaVisitor
Text
Text
Attributes
- Inherited from:
- SchemaVisitor
Map with keys of String/Text type
Map with keys of String/Text type
Attributes
- Inherited from:
- SchemaVisitor
Timestamp
Timestamp
Attributes
- Inherited from:
- SchemaVisitor
Unit
Unit
Attributes
- Inherited from:
- SchemaVisitor
Type Variable.
Type Variable.
Codecs will use substitution, effectively replacing type variables with concrete types, while code generators will use type variable names.
Attributes
- Inherited from:
- SchemaVisitor